Documentation
¶
Index ¶
- type NexusAlgorithmTemplateLister
- type NexusAlgorithmTemplateListerExpansion
- type NexusAlgorithmTemplateNamespaceLister
- type NexusAlgorithmTemplateNamespaceListerExpansion
- type NexusAlgorithmWorkgroupLister
- type NexusAlgorithmWorkgroupListerExpansion
- type NexusAlgorithmWorkgroupNamespaceLister
- type NexusAlgorithmWorkgroupNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NexusAlgorithmTemplateLister ¶ added in v1.0.0
type NexusAlgorithmTemplateLister interface {
// List lists all NexusAlgorithmTemplates in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*sciencev1.NexusAlgorithmTemplate, err error)
// NexusAlgorithmTemplates returns an object that can list and get NexusAlgorithmTemplates.
NexusAlgorithmTemplates(namespace string) NexusAlgorithmTemplateNamespaceLister
NexusAlgorithmTemplateListerExpansion
}
NexusAlgorithmTemplateLister helps list NexusAlgorithmTemplates. All objects returned here must be treated as read-only.
func NewNexusAlgorithmTemplateLister ¶ added in v1.0.0
func NewNexusAlgorithmTemplateLister(indexer cache.Indexer) NexusAlgorithmTemplateLister
NewNexusAlgorithmTemplateLister returns a new NexusAlgorithmTemplateLister.
type NexusAlgorithmTemplateListerExpansion ¶ added in v1.0.0
type NexusAlgorithmTemplateListerExpansion interface{}
NexusAlgorithmTemplateListerExpansion allows custom methods to be added to NexusAlgorithmTemplateLister.
type NexusAlgorithmTemplateNamespaceLister ¶ added in v1.0.0
type NexusAlgorithmTemplateNamespaceLister interface {
// List lists all NexusAlgorithmTemplates in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*sciencev1.NexusAlgorithmTemplate, err error)
// Get retrieves the NexusAlgorithmTemplate from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*sciencev1.NexusAlgorithmTemplate, error)
NexusAlgorithmTemplateNamespaceListerExpansion
}
NexusAlgorithmTemplateNamespaceLister helps list and get NexusAlgorithmTemplates. All objects returned here must be treated as read-only.
type NexusAlgorithmTemplateNamespaceListerExpansion ¶ added in v1.0.0
type NexusAlgorithmTemplateNamespaceListerExpansion interface{}
NexusAlgorithmTemplateNamespaceListerExpansion allows custom methods to be added to NexusAlgorithmTemplateNamespaceLister.
type NexusAlgorithmWorkgroupLister ¶ added in v1.0.0
type NexusAlgorithmWorkgroupLister interface {
// List lists all NexusAlgorithmWorkgroups in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*sciencev1.NexusAlgorithmWorkgroup, err error)
// NexusAlgorithmWorkgroups returns an object that can list and get NexusAlgorithmWorkgroups.
NexusAlgorithmWorkgroups(namespace string) NexusAlgorithmWorkgroupNamespaceLister
NexusAlgorithmWorkgroupListerExpansion
}
NexusAlgorithmWorkgroupLister helps list NexusAlgorithmWorkgroups. All objects returned here must be treated as read-only.
func NewNexusAlgorithmWorkgroupLister ¶ added in v1.0.0
func NewNexusAlgorithmWorkgroupLister(indexer cache.Indexer) NexusAlgorithmWorkgroupLister
NewNexusAlgorithmWorkgroupLister returns a new NexusAlgorithmWorkgroupLister.
type NexusAlgorithmWorkgroupListerExpansion ¶ added in v1.0.0
type NexusAlgorithmWorkgroupListerExpansion interface{}
NexusAlgorithmWorkgroupListerExpansion allows custom methods to be added to NexusAlgorithmWorkgroupLister.
type NexusAlgorithmWorkgroupNamespaceLister ¶ added in v1.0.0
type NexusAlgorithmWorkgroupNamespaceLister interface {
// List lists all NexusAlgorithmWorkgroups in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*sciencev1.NexusAlgorithmWorkgroup, err error)
// Get retrieves the NexusAlgorithmWorkgroup from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*sciencev1.NexusAlgorithmWorkgroup, error)
NexusAlgorithmWorkgroupNamespaceListerExpansion
}
NexusAlgorithmWorkgroupNamespaceLister helps list and get NexusAlgorithmWorkgroups. All objects returned here must be treated as read-only.
type NexusAlgorithmWorkgroupNamespaceListerExpansion ¶ added in v1.0.0
type NexusAlgorithmWorkgroupNamespaceListerExpansion interface{}
NexusAlgorithmWorkgroupNamespaceListerExpansion allows custom methods to be added to NexusAlgorithmWorkgroupNamespaceLister.